Package: irg
Title: Instantaneous Rate of Green Up
Version: 0.1.6
Authors@R: 
    person(given = "Alec L.",
           family = "Robitaille",
           role = c("aut", "cre"),
           email = "robit.alec@gmail.com",
           comment = c(ORCID = "0000-0002-4706-1762"))
Description: Fits a double logistic function to NDVI time series and calculates 
             instantaneous rate of green (IRG) according to methods described
             in Bischoff et al. (2012) <doi:10.1086/667590>. 
License: GPL-3
Encoding: UTF-8
RoxygenNote: 7.1.2
Suggests: knitr, rmarkdown, DiagrammeR, ggplot2, curl, tinytest
Depends: R (>= 2.10)
Imports: data.table, RcppRoll, stats, chk
VignetteBuilder: knitr
URL: https://github.com/robitalec/irg, https://robitalec.github.io/irg/
BugReports: https://github.com/robitalec/irg/issues
NeedsCompilation: no
Packaged: 2021-12-22 02:06:27 UTC; alecr
Author: Alec L. Robitaille [aut, cre] (<https://orcid.org/0000-0002-4706-1762>)
Maintainer: Alec L. Robitaille <robit.alec@gmail.com>
Repository: CRAN
Date/Publication: 2021-12-22 03:10:02 UTC
Built: R 4.6.0; ; 2026-04-27 10:13:31 UTC; unix
