---
title: "Example Earth Engine scripts"
output: rmarkdown::html_vignette
author: 'Alec L. Robitaille'
date: '`r Sys.Date()`'
vignette: >
  %\VignetteIndexEntry{example-scripts}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = ""
)
```

```{r setup}
library(irg)
```

Just swap the regions with your own features or points and run!


## MODIS MOD13Q1 

To access an example script for extracting NDVI from
MODIS MOD13Q1 imagery in Earth Engine, run: 

```{r}
use_example_ee_script(sensor = 'MODIS')
```


## Landsat 8

To access an example script for extracting NDVI from
Landsat 8 imagery in Earth Engine, run: 

```{r, eval = TRUE}
use_example_ee_script(sensor = 'Landsat')
```
